Checks that the column(s) listed in config$key_columns have no
duplicate values. When key_columns is a single string, one result is
returned for that column. When it is a character vector of length > 1, a
single result covering the composite key is returned. Returns an empty list
if key_columns is not configured.
Arguments
- df
A data frame with all columns as character vectors (as returned by
read_dataset).- config
Named list. Merged configuration as returned by
load_config.
Value
A list of dq_result objects. Status is "FAIL"
when duplicates or missing key columns are detected; "PASS"
otherwise. Returns an empty list if key_columns is not configured.
Examples
cfg_dir <- system.file("demonstrations/config", package = "dqcheckr")
cfg <- load_config("starwars_csv", config_dir = cfg_dir)
path <- system.file("demonstrations/data/starwars.csv", package = "dqcheckr")
df <- read_dataset(path, cfg)
check_key_uniqueness(df, cfg)
#> [[1]]
#> [[1]]$check_id
#> [1] "QC-12"
#>
#> [[1]]$check_name
#> [1] "Key uniqueness"
#>
#> [[1]]$column
#> [1] "name"
#>
#> [[1]]$status
#> [1] "PASS"
#>
#> [[1]]$observed
#> [1] "0 duplicate value(s) found"
#>
#> [[1]]$threshold
#> [1] NA
#>
#> [[1]]$message
#> [1] "Key column 'name' has all unique values."
#>
#>